@@ -38,7 +38,7 @@ async fn main() -> io::Result<()> {
 
     let config_resolved = env::Vars::apply(config.to_string());
 
-    chewdata::exec(serde_json::from_str(config_resolved.as_str())?, None)
+    chewdata::exec(serde_json::from_str(config_resolved.as_str())?, None, None)
         .with_subscriber(subscriber)
         .await?;
 
